==> maven_3.5.4.orig.tar.xz: maven-maven-3.5.4/maven-model/src/test/java/org/apache/maven/model/DeploymentRepositoryTest.java <==
package org.apache.maven.model;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import junit.framework.TestCase;

/**
 * Tests {@code DeploymentRepository}.
 *
 * @author Benjamin Bentmann
 */
public class DeploymentRepositoryTest
    extends TestCase
{

    public void testHashCodeNullSafe()
    {
        new DeploymentRepository().hashCode();
    }

    public void testEqualsNullSafe()
    {
        assertFalse( new DeploymentRepository().equals( null ) );

        new DeploymentRepository().equals( new DeploymentRepository() );
    }

    public void testEqualsIdentity()
    {
        DeploymentRepository thing = new DeploymentRepository();
        assertTrue( thing.equals( thing ) );
    }

    public void testToStringNullSafe()
    {
        assertNotNull( new DeploymentRepository().toString() );
    }

}

==> maven_3.9.9.orig.tar.xz: maven-maven-3.9.9/maven-model/src/test/java/org/apache/maven/model/DeploymentRepositoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.model;

import junit.framework.TestCase;

/**
 * Tests {@code DeploymentRepository}.
 *
 * @author Benjamin Bentmann
 */
public class DeploymentRepositoryTest extends TestCase {

    public void testHashCodeNullSafe() {
        new DeploymentRepository().hashCode();
    }

    public void testEqualsNullSafe() {
        assertFalse(new DeploymentRepository().equals(null));

        new DeploymentRepository().equals(new DeploymentRepository());
    }

    public void testEqualsIdentity() {
        DeploymentRepository thing = new DeploymentRepository();
        assertTrue(thing.equals(thing));
    }

    public void testToStringNullSafe() {
        assertNotNull(new DeploymentRepository().toString());
    }
}
